/*  FileApart splits files into smaller fragments and reassembles these 
 *  fragments at the desired destination.
 *  Copyright (C) 2008 by Markus Walther
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package fileapart.ui;

import fileapart.*;
import javax.swing.*;
import javax.swing.filechooser.*;
import java.awt.event.*;

/**
 *
 * @author  Markus Walther (mwthp@web.de)
 */
public class FileApartUI extends javax.swing.JFrame {

  chopAndMergeFiles eventHandler;
  JFileChooser fileChDlg;
  Timer checkTimer;
  ActionListener alCheck;
  boolean useTimer;
  JTextArea curTextArea;
  static String globalArgs[];
  boolean languageGer;
  java.awt.Cursor waitCursor;
  java.awt.Cursor defaultCursor;
  FileOverwriteOkCancelDialog overwriteFileDlg;
  String owFileMsg;
  String abortMsg;


  /** Creates new form FileChopper */
  public FileApartUI() {
    initComponents();
    curTextArea = jTextAreaChop;
    eventHandler = new chopAndMergeFiles(){
      @Override
      public void showMessage(String message){
        curTextArea.append(message+"\n");
        super.showMessage(message);
      }
      @Override
      public int launchOverwriteDialog(String fname){
        return overwriteDialog(fname);
      }
    };

    fileChDlg = new JFileChooser();
    //german language localization
    languageGer = false;
    if(globalArgs.length > 0){
      if(globalArgs[0].equals("-de")){
        languageGer = true;
      }
    }
    owFileMsg = " is already existing.\nOverwrite?";
    abortMsg = "Aborted by user.";
    if(languageGer)
      localizeGerman();
    //Cursor
    waitCursor = new java.awt.Cursor(java.awt.Cursor.WAIT_CURSOR);
    defaultCursor = new java.awt.Cursor(java.awt.Cursor.DEFAULT_CURSOR);
    //Timer
    useTimer = false;
    if(useTimer){
      alCheck = new ActionListener(){
        @Override
        public void actionPerformed(ActionEvent evt) {
          checkMandatories();
        }
      };
      checkTimer = new Timer(500, alCheck);
      checkTimer.start();
    }
     
  }
  
  private int overwriteDialog(String filename){
    int status;
    FileOverwriteOkCancelDialog owDlg = new FileOverwriteOkCancelDialog(this,true);
    owDlg.setTextMessage(filename + owFileMsg);
    if(languageGer)
      owDlg.localizeGerman();
    owDlg.setVisible(true);
    status = owDlg.getReturnStatus();
    if(status == chopAndMergeFiles.RET_NO)
      eventHandler.showMessage(abortMsg);
    return status;
  }
  
  private void localizeGerman(){
    jButtonOpenChopFile.setText("Datei auswählen");
    jButtonChopFragmentFolder.setText("Zielordner");
    jCheckBoxChopShowHidden.setText("versteckte Dateien anzeigen");
    jLabelMaxSize.setText("Maximale Größe:");
    jButton4.setText("Erstes Fragment");
    jButton5.setText("Zielordner");
    jCheckBox2.setText("versteckte Dateien anzeigen");
    jButton7.setText("Beenden");
    jLabel2.setText("Verlauf");
    jLabel3.setText("Verlauf");
    jMenu1.setText("Hilfe");
    jMenuItem1.setText("Über...");
    owFileMsg = " existiert bereits!\nDatei überschreiben?";
  }
  
  private void setCurTextArea(JTextArea textArea){
    curTextArea = textArea;
  }
  
  private void checkMandatories(){
    String ftcName;
    String fileddName;
    String fffName;
    String fragddName;
    //get user supplied data
    ftcName = jTextFieldChopFile.getText();
    fileddName = jTextFieldChopFragmentFolder.getText();
    fffName = jTextField3.getText();
    fragddName = jTextField4.getText();
    //set data
    eventHandler.setFileToChop(ftcName);
    eventHandler.setFragDestDir(fileddName);
    eventHandler.setFirstFragment(fffName);
    eventHandler.setFileDestDir(fragddName);
    eventHandler.setFragSize(getFragSize());
    //check data
    jButtonChopStart.setEnabled(eventHandler.checkMandatoriesForChopping());
    jButton6.setEnabled(eventHandler.checkMandatoriesForAssembling());
  }

  private long getFragSize(){
    String sSize = jSpinnerLenCount.getValue().toString();
    long size;
    int exponent = jComboBoxMagnifier.getSelectedIndex();

    if(sSize.isEmpty())
      return 0;
    try{
      size = Long.valueOf(sSize);
    } catch(NumberFormatException nfe) {
      return 0;
    }
    size = size<<(exponent*10);
    return size;
  }
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
  private void initComponents() {

    jPanelChop = new javax.swing.JPanel();
    jButtonOpenChopFile = new javax.swing.JButton();
    jButtonChopStart = new javax.swing.JButton();
    jButtonChopFragmentFolder = new javax.swing.JButton();
    jLabelMaxSize = new javax.swing.JLabel();
    jComboBoxMagnifier = new javax.swing.JComboBox();
    jSpinnerLenCount = new javax.swing.JSpinner();
    jScrollPane1 = new javax.swing.JScrollPane();
    jTextAreaChop = new javax.swing.JTextArea();
    jLabel2 = new javax.swing.JLabel();
    jCheckBoxChopShowHidden = new javax.swing.JCheckBox();
    jTextFieldChopFile = new javax.swing.JTextField();
    jTextFieldChopFragmentFolder = new javax.swing.JTextField();
    jPanelReassemble = new javax.swing.JPanel();
    jButton4 = new javax.swing.JButton();
    jTextField3 = new javax.swing.JTextField();
    jButton5 = new javax.swing.JButton();
    jTextField4 = new javax.swing.JTextField();
    jButton6 = new javax.swing.JButton();
    jScrollPane2 = new javax.swing.JScrollPane();
    jTextArea2 = new javax.swing.JTextArea();
    jLabel3 = new javax.swing.JLabel();
    jCheckBox2 = new javax.swing.JCheckBox();
    jButton7 = new javax.swing.JButton();
    jMenuBar1 = new javax.swing.JMenuBar();
    jMenu1 = new javax.swing.JMenu();
    jMenuItem1 = new javax.swing.JMenuItem();

    setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
    setTitle("FileApart");

    jPanelChop.setBorder(javax.swing.BorderFactory.createTitledBorder("Chop File"));

    jButtonOpenChopFile.setText("Select File");
    jButtonOpenChopFile.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        jButtonOpenChopFileActionPerformed(evt);
      }
    });

    jButtonChopStart.setText("Start");
    jButtonChopStart.setEnabled(false);
    jButtonChopStart.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        jButtonChopStartActionPerformed(evt);
      }
    });

    jButtonChopFragmentFolder.setText("Output Folder");
    jButtonChopFragmentFolder.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        jButtonChopFragmentFolderActionPerformed(evt);
      }
    });

    jLabelMaxSize.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
    jLabelMaxSize.setText("Maximal Size: ");

    jComboBoxMagnifier.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "Byte", "kB", "MB", "GB" }));
    jComboBoxMagnifier.setSelectedIndex(1);
    jComboBoxMagnifier.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        jComboBoxMagnifierItemStateChanged(evt);
      }
    });

    jSpinnerLenCount.addChangeListener(new javax.swing.event.ChangeListener() {
      public void stateChanged(javax.swing.event.ChangeEvent evt) {
        jSpinnerLenCountStateChanged(evt);
      }
    });

    jTextAreaChop.setColumns(20);
    jTextAreaChop.setEditable(false);
    jTextAreaChop.setLineWrap(true);
    jTextAreaChop.setRows(5);
    jScrollPane1.setViewportView(jTextAreaChop);

    jLabel2.setText("Messages:");

    jCheckBoxChopShowHidden.setText("Show hidden files and folders");

    jTextFieldChopFile.setEditable(false);

    jTextFieldChopFragmentFolder.setEditable(false);

    javax.swing.GroupLayout jPanelChopLayout = new javax.swing.GroupLayout(jPanelChop);
    jPanelChop.setLayout(jPanelChopLayout);
    jPanelChopLayout.setHorizontalGroup(
      jPanelChopLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
      .addGroup(jPanelChopLayout.createSequentialGroup()
        .addContainerGap()
        .addGroup(jPanelChopLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
          .addComponent(jCheckBoxChopShowHidden, javax.swing.GroupLayout.DEFAULT_SIZE, 435, Short.MAX_VALUE)
          .addGroup(jPanelChopLayout.createSequentialGroup()
            .addGroup(jPanelChopLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
              .addComponent(jLabelMaxSize, javax.swing.GroupLayout.PREFERRED_SIZE, 127, javax.swing.GroupLayout.PREFERRED_SIZE)
              .addComponent(jButtonChopFragmentFolder, javax.swing.GroupLayout.PREFERRED_SIZE, 139, javax.swing.GroupLayout.PREFERRED_SIZE)
              .addComponent(jButtonOpenChopFile, javax.swing.GroupLayout.PREFERRED_SIZE, 139, javax.swing.GroupLayout.PREFERRED_SIZE)
              .addComponent(jButtonChopStart, javax.swing.GroupLayout.PREFERRED_SIZE, 139, javax.swing.GroupLayout.PREFERRED_SIZE))
            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
            .addGroup(jPanelChopLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
              .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 284, Short.MAX_VALUE)
              .addGroup(jPanelChopLayout.createSequentialGroup()
                .addComponent(jSpinnerLenCount, javax.swing.GroupLayout.PREFERRED_SIZE, 90, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jComboBoxMagnifier, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
              .addComponent(jLabel2, javax.swing.GroupLayout.DEFAULT_SIZE, 284, Short.MAX_VALUE)
              .addComponent(jTextFieldChopFragmentFolder, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 284, Short.MAX_VALUE)
              .addComponent(jTextFieldChopFile, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 284, Short.MAX_VALUE))))
        .addContainerGap())
    );
    jPanelChopLayout.setVerticalGroup(
      jPanelChopLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
      .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, jPanelChopLayout.createSequentialGroup()
        .addGroup(jPanelChopLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
          .addComponent(jTextFieldChopFile, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
          .addComponent(jButtonOpenChopFile))
        .addGap(9, 9, 9)
        .addGroup(jPanelChopLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
          .addComponent(jTextFieldChopFragmentFolder, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
          .addComponent(jButtonChopFragmentFolder))
        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
        .addComponent(jCheckBoxChopShowHidden)
        .addGap(18, 18, 18)
        .addGroup(jPanelChopLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
          .addComponent(jLabelMaxSize)
          .addComponent(jSpinnerLenCount, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
          .addComponent(jComboBoxMagnifier, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
        .addGap(18, 18, 18)
        .addComponent(jLabel2)
        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
        .addGroup(jPanelChopLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
          .addComponent(jButtonChopStart)
          .addComponent(jScrollPane1, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
        .addGap(82, 82, 82))
    );

    jPanelReassemble.setBorder(javax.swing.BorderFactory.createTitledBorder("Reassemble File"));

    jButton4.setText("First Fragment");
    jButton4.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        jButton4ActionPerformed(evt);
      }
    });

    jTextField3.setEditable(false);

    jButton5.setText("Output Folder");
    jButton5.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        jButton5ActionPerformed(evt);
      }
    });

    jTextField4.setEditable(false);

    jButton6.setText("Start");
    jButton6.setEnabled(false);
    jButton6.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        jButton6ActionPerformed(evt);
      }
    });

    jTextArea2.setColumns(20);
    jTextArea2.setEditable(false);
    jTextArea2.setLineWrap(true);
    jTextArea2.setRows(5);
    jScrollPane2.setViewportView(jTextArea2);

    jLabel3.setText("Messages:");

    jCheckBox2.setText("Show hidden files and folders");

    javax.swing.GroupLayout jPanelReassembleLayout = new javax.swing.GroupLayout(jPanelReassemble);
    jPanelReassemble.setLayout(jPanelReassembleLayout);
    jPanelReassembleLayout.setHorizontalGroup(
      jPanelReassembleLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
      .addGroup(jPanelReassembleLayout.createSequentialGroup()
        .addContainerGap()
        .addGroup(jPanelReassembleLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
          .addComponent(jCheckBox2, javax.swing.GroupLayout.Alignment.TRAILING, javax.swing.GroupLayout.DEFAULT_SIZE, 435, Short.MAX_VALUE)
          .addGroup(jPanelReassembleLayout.createSequentialGroup()
            .addGroup(jPanelReassembleLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING, false)
              .addComponent(jButton4, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
              .addComponent(jButton5, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
              .addComponent(jButton6, javax.swing.GroupLayout.DEFAULT_SIZE, 139, Short.MAX_VALUE))
            .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
            .addGroup(jPanelReassembleLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
              .addComponent(jLabel3, javax.swing.GroupLayout.DEFAULT_SIZE, 284, Short.MAX_VALUE)
              .addComponent(jTextField3, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 284, Short.MAX_VALUE)
              .addComponent(jTextField4, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 284, Short.MAX_VALUE)
              .addComponent(jScrollPane2, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 284, Short.MAX_VALUE))))
        .addContainerGap())
    );
    jPanelReassembleLayout.setVerticalGroup(
      jPanelReassembleLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
      .addGroup(jPanelReassembleLayout.createSequentialGroup()
        .addGroup(jPanelReassembleLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
          .addComponent(jButton4)
          .addComponent(jTextField3, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
        .addGap(9, 9, 9)
        .addGroup(jPanelReassembleLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
          .addComponent(jButton5)
          .addComponent(jTextField4, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
        .addComponent(jCheckBox2)
        .addGap(18, 18, 18)
        .addComponent(jLabel3)
        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
        .addGroup(jPanelReassembleLayout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
          .addComponent(jButton6)
          .addComponent(jScrollPane2, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
        .addContainerGap())
    );

    jButton7.setText("Close");
    jButton7.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        jButton7ActionPerformed(evt);
      }
    });

    jMenu1.setText("Help");

    jMenuItem1.setText("About...");
    jMenuItem1.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        jMenuItem1ActionPerformed(evt);
      }
    });
    jMenu1.add(jMenuItem1);

    jMenuBar1.add(jMenu1);

    setJMenuBar(jMenuBar1);

    javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
    getContentPane().setLayout(layout);
    layout.setHorizontalGroup(
      layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
      .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
        .addContainerGap()
        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
          .addComponent(jPanelChop, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
          .addComponent(jButton7, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.PREFERRED_SIZE, 114, javax.swing.GroupLayout.PREFERRED_SIZE)
          .addComponent(jPanelReassemble, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        .addContainerGap())
    );
    layout.setVerticalGroup(
      layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
      .addGroup(layout.createSequentialGroup()
        .addContainerGap()
        .addComponent(jPanelChop, javax.swing.GroupLayout.PREFERRED_SIZE, 283, javax.swing.GroupLayout.PREFERRED_SIZE)
        .addGap(18, 18, 18)
        .addComponent(jPanelReassemble, javax.swing.GroupLayout.DEFAULT_SIZE, 228, Short.MAX_VALUE)
        .addGap(18, 18, 18)
        .addComponent(jButton7)
        .addGap(18, 18, 18))
    );

    pack();
  }// </editor-fold>//GEN-END:initComponents
    private void jButton7ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButton7ActionPerformed
      if(useTimer)
        checkTimer.stop();
      eventHandler.onExit();
    }//GEN-LAST:event_jButton7ActionPerformed

    private void jButtonOpenChopFileActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButtonOpenChopFileActionPerformed
      String fName;
      fileChDlg.setFileHidingEnabled(!jCheckBoxChopShowHidden.isSelected());
      fileChDlg.setFileSelectionMode(JFileChooser.FILES_ONLY);
      if (fileChDlg.showOpenDialog(this) == JFileChooser.APPROVE_OPTION) {
        fName = fileChDlg.getSelectedFile().getAbsolutePath();
        jTextFieldChopFile.setText(fName);
      }
      checkMandatories();
    }//GEN-LAST:event_jButtonOpenChopFileActionPerformed

    private void jButtonChopFragmentFolderActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButtonChopFragmentFolderActionPerformed
      String fName;
      fileChDlg.setFileHidingEnabled(!jCheckBoxChopShowHidden.isSelected());
      fileChDlg.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
      if (fileChDlg.showOpenDialog(this) == JFileChooser.APPROVE_OPTION) {
        fName = fileChDlg.getSelectedFile().getAbsolutePath();
        jTextFieldChopFragmentFolder.setText(fName);
      }
      checkMandatories();
    }//GEN-LAST:event_jButtonChopFragmentFolderActionPerformed

    private void jButton4ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButton4ActionPerformed
      String fName;
      FileFilter filter = new FileNameExtensionFilter("First FileChopper fragment files (*.000)","000");
      
      fileChDlg.setFileHidingEnabled(!jCheckBox2.isSelected());
      fileChDlg.setFileSelectionMode(JFileChooser.FILES_ONLY);
      fileChDlg.addChoosableFileFilter(filter);
      fileChDlg.setFileFilter(filter);
      if (fileChDlg.showOpenDialog(this) == JFileChooser.APPROVE_OPTION) {
        fName = fileChDlg.getSelectedFile().getAbsolutePath();
        jTextField3.setText(fName);
      }
      fileChDlg.removeChoosableFileFilter(filter);
      fileChDlg.setAcceptAllFileFilterUsed(true);
      checkMandatories();
    }//GEN-LAST:event_jButton4ActionPerformed

    private void jButton5ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButton5ActionPerformed
      String fName;
      fileChDlg.setFileHidingEnabled(!jCheckBox2.isSelected());
      fileChDlg.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
      if (fileChDlg.showOpenDialog(this) == JFileChooser.APPROVE_OPTION) {
        fName = fileChDlg.getSelectedFile().getAbsolutePath();
        jTextField4.setText(fName);
      }
      checkMandatories();
    }//GEN-LAST:event_jButton5ActionPerformed

    private void jSpinnerLenCountStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_jSpinnerLenCountStateChanged
      if(getFragSize()<0){
        jSpinnerLenCount.setValue(0);
      }
      checkMandatories();
    }//GEN-LAST:event_jSpinnerLenCountStateChanged

    private void jButtonChopStartActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButtonChopStartActionPerformed
      setCurTextArea(jTextAreaChop);
      if(!eventHandler.initFileChopping())
        return;
      setCursor(waitCursor);
      eventHandler.chopFile(true);
      setCursor(defaultCursor);
    }//GEN-LAST:event_jButtonChopStartActionPerformed

    private void jButton6ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButton6ActionPerformed
      setCurTextArea(jTextArea2);
      setCursor(waitCursor);
      if(!eventHandler.initFileAssembly())
        return;
      eventHandler.reassembleFile(true);
      setCursor(defaultCursor);
    }//GEN-LAST:event_jButton6ActionPerformed

    private void jMenuItem1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jMenuItem1ActionPerformed
      NewJDialog.main(globalArgs);
    }//GEN-LAST:event_jMenuItem1ActionPerformed

    private void jComboBoxMagnifierItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_jComboBoxMagnifierItemStateChanged
      checkMandatories();
    }//GEN-LAST:event_jComboBoxMagnifierItemStateChanged

  /**
   * @param args the command line arguments
   */
  public static void main(String args[]) {
    java.awt.EventQueue.invokeLater(new Runnable() {

      @Override
      public void run() {
        new FileApartUI().setVisible(true);
      }
    });
    globalArgs = args;
  }
  // Variables declaration - do not modify//GEN-BEGIN:variables
  private javax.swing.JButton jButton4;
  private javax.swing.JButton jButton5;
  private javax.swing.JButton jButton6;
  private javax.swing.JButton jButton7;
  private javax.swing.JButton jButtonChopFragmentFolder;
  private javax.swing.JButton jButtonChopStart;
  private javax.swing.JButton jButtonOpenChopFile;
  private javax.swing.JCheckBox jCheckBox2;
  private javax.swing.JCheckBox jCheckBoxChopShowHidden;
  private javax.swing.JComboBox jComboBoxMagnifier;
  private javax.swing.JLabel jLabel2;
  private javax.swing.JLabel jLabel3;
  private javax.swing.JLabel jLabelMaxSize;
  private javax.swing.JMenu jMenu1;
  private javax.swing.JMenuBar jMenuBar1;
  private javax.swing.JMenuItem jMenuItem1;
  private javax.swing.JPanel jPanelChop;
  private javax.swing.JPanel jPanelReassemble;
  private javax.swing.JScrollPane jScrollPane1;
  private javax.swing.JScrollPane jScrollPane2;
  private javax.swing.JSpinner jSpinnerLenCount;
  private javax.swing.JTextArea jTextArea2;
  private javax.swing.JTextArea jTextAreaChop;
  private javax.swing.JTextField jTextField3;
  private javax.swing.JTextField jTextField4;
  private javax.swing.JTextField jTextFieldChopFile;
  private javax.swing.JTextField jTextFieldChopFragmentFolder;
  // End of variables declaration//GEN-END:variables
}
